//
//  AmityChatFileViewCell.swift
//  SampleApp
//
//  Created by Michael Abadi Santoso on 10/11/19.
//  Copyright © 2019 David Zhang. All rights reserved.
//

import UIKit
import AmitySDK

final class AmityChatFileViewCell: UITableViewCell, AmityChatCellProtocol {
    
    @IBOutlet weak var myImageView: UIImageView!
    @IBOutlet weak var displayNameLabel: UILabel!
    @IBOutlet weak var timeLabel: UILabel!
    @IBOutlet weak var messageStatusImageView: UIImageView!
    @IBOutlet weak var containerView: UIView!
    
    private var messageId: String?
    
    override func awakeFromNib() {
        super.awakeFromNib()
        messageStatusImageView.accessibilityIdentifier = "chat.message-cell.statusImageView"
        myImageView.backgroundColor = UIColor.systemGroupedBackground
        myImageView.contentMode = .scaleAspectFit
        
        containerView.backgroundColor = UIColor.systemGroupedBackground
        containerView.addRoundedCorner(radius: 8)
    }
    
    private func set(image: UIImage) {
        myImageView.image = image
    }
    
    func display(_ message: AmityMessage, client: AmityClient) {
        messageId = message.messageId
        
        if message.isDeleted {
            displayNameLabel.text = "Message deleted"
        } else {
            let flagCount = message.flagCount
            displayNameLabel.text = message.user?.displayName ?? "" + " F: \(flagCount)"
            messageStatusImageView.image = message.syncState.symbolImage()
            messageStatusImageView.accessibilityIdentifier = "chat.message-cell.statusImageView-\(message.syncState)"
            myImageView.image = UIImage(named:"file")
            timeLabel.text = DateFormatter.localizedString(from: message.createdAt, dateStyle: .none, timeStyle: .short)
            
            if !message.isDeleted {
                let audioIcon = UIImage(systemName: "waveform")
                
                let iconConfiguration = UIImage.SymbolConfiguration(pointSize: 30, weight: .regular)
                let fileIcon = UIImage(systemName: "doc", withConfiguration: iconConfiguration)
                                
                self.myImageView.tintColor = UIColor.gray
                self.myImageView.preferredSymbolConfiguration = iconConfiguration
                self.myImageView.image = message.messageType == .audio ? audioIcon : fileIcon
                
                guard let fileInfo = message.getFileInfo() else { return }
                
                Log.add(info: "\nAudio Message:")
                Log.add(info: "Message Id: \(message.messageId)")
                Log.add(info: "File Id: \(fileInfo.fileId)")
                Log.add(info: "File URL: \(fileInfo.fileURL)")
            }
        }
    }
    
    override func prepareForReuse() {
        super.prepareForReuse()
        myImageView.image = nil
        timeLabel.text = ""
        messageStatusImageView.image = nil
    }
}

extension AmityMessageType {
    
    var description: String {
        switch self {
        case .audio:
            return "Audio"
        case .image:
            return "Image"
        case .file:
            return "File"
        case .custom:
            return "Custom"
        case .text:
            return "Text"
        case .video:
            return "Video"
        @unknown default:
            return "Unknown"
        }
    }
}
