//
//  PhotoPicker.swift
//  SampleApp
//
//  Created by Nishan Niraula on 15/2/2566 BE.
//  Copyright © 2566 BE David Zhang. All rights reserved.
//

import SwiftUI
import PhotosUI

struct PhotoPicker: UIViewControllerRepresentable {
    @Binding var pickerResult: [UIImage]
    @Binding var isPresented: Bool
    
    func makeUIViewController(context: Context) -> some UIViewController {
        var configuration = PHPickerConfiguration(photoLibrary: PHPhotoLibrary.shared())
        configuration.filter = .images    // filter only to images
        configuration.selectionLimit = 10 // ignore limit
        configuration.preferredAssetRepresentationMode = .current
        
        let photoPickerViewController = PHPickerViewController(configuration: configuration)
        photoPickerViewController.delegate = context.coordinator
        return photoPickerViewController
    }
    
    func updateUIViewController(_ uiViewController: UIViewControllerType, context: Context) { }
    
    func makeCoordinator() -> Coordinator {
        Coordinator(self)
    }
    
    class Coordinator: PHPickerViewControllerDelegate {
        private let parent: PhotoPicker
        
        init(_ parent: PhotoPicker) {
            self.parent = parent
        }
        
        func picker(_ picker: PHPickerViewController, didFinishPicking results: [PHPickerResult]) {
            guard !results.isEmpty else {
                parent.isPresented = false
                picker.dismiss(animated: true)
                return
            }
            
            for image in results {
                if image.itemProvider.canLoadObject(ofClass: UIImage.self) {
                    
                    image.itemProvider.loadObject(ofClass: UIImage.self) { [weak self] newImage, error in
                        if let error = error {
                            print("Can't load image \(error.localizedDescription)")
                        } else if let image = newImage as? UIImage {
                            DispatchQueue.main.async {
                                self?.parent.pickerResult.append(image)
                            }
                        }
                    }
                }
            }
            
            parent.isPresented = false
            picker.dismiss(animated: true)
        }
    }
}
